@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator::App;
-$Games::ABC_Path::Generator::App::VERSION = '0.4.1';
+$Games::ABC_Path::Generator::App::VERSION = '0.4.2';
 use 5.006;
 use strict;
 use warnings;
@@ -27,9 +27,9 @@ sub _argv
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    $self->_argv($args->{argv});
+    $self->_argv( $args->{argv} );
 
     return;
 }
@@ -41,15 +41,17 @@ sub run
 
     my $seed;
     my $mode = 'riddle';
-    my $man = 0;
+    my $man  = 0;
     my $help = 0;
-    if (!GetOptionsFromArray(
+    if (
+        !GetOptionsFromArray(
             $self->_argv(),
             'seed=i' => \$seed,
             'mode=s' => \$mode,
             'help|h' => \$help,
-            man => \$man,
-        ))
+            man      => \$man,
+        )
+        )
     {
         pod2usage(2);
     }
@@ -60,32 +62,27 @@ sub run
     }
     elsif ($man)
     {
-        pod2usage(-verbose => 2);
+        pod2usage( -verbose => 2 );
     }
-    elsif (!defined($seed))
+    elsif ( !defined($seed) )
     {
         die "Seed not specified! See --help.";
     }
     else
     {
-        my $gen = Games::ABC_Path::Generator->new({ seed => $seed, });
+        my $gen = Games::ABC_Path::Generator->new( { seed => $seed, } );
 
-        if ($mode eq 'final')
+        if ( $mode eq 'final' )
         {
-            print $gen->calc_final_layout()->as_string({});
+            print $gen->calc_final_layout()->as_string( {} );
         }
-        elsif ($mode eq 'riddle')
+        elsif ( $mode eq 'riddle' )
         {
-            my $riddle = $gen->calc_riddle();
-
-            my $layout_string = $riddle->get_final_layout_as_string({});
-
+            my $riddle        = $gen->calc_riddle();
             my $riddle_string = $riddle->get_riddle_v1_string;
 
-            print sprintf(
-                "ABC Path Solver Layout Version 1:\n%s",
-                $riddle_string,
-            );
+            print sprintf( "ABC Path Solver Layout Version 1:\n%s",
+                $riddle_string, );
         }
 
     }
@@ -93,7 +90,7 @@ sub run
 }
 
 
-1; # End of Games::ABC_Path::Generator::App
+1;    # End of Games::ABC_Path::Generator::App
 
 __END__
 
@@ -107,22 +104,18 @@ Games::ABC_Path::Generator::App - command line application for the ABC Path gene
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
     use Games::ABC_Path::Generator::App;
 
-    my $app = Games::ABC_Path::Generator::App->new({ argv => [@ARGV], },);
+    my $app = Games::ABC_Path::Generator::App->new({ argv => \@ARGV, },);
     $app->run();
 
-=head1 VERSION
-
-version 0.4.1
-
 =head1 SUBROUTINES/METHODS
 
-=head2 Games::ABC_Path::Generator::App->new({ argv => [@ARGV], },);
+=head2 Games::ABC_Path::Generator::App->new({ argv => \@ARGV, },);
 
 Initialize from @ARGV .
 
@@ -168,43 +161,13 @@ L<http://search.cpan.org/dist/Games-ABC_Path-Generator/>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Shlomi Fish.
-
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2019 by Shlomi Fish.
 
 This is free software, licensed under:
 
