@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator::Base;
-$Games::ABC_Path::Generator::Base::VERSION = '0.4.1';
+$Games::ABC_Path::Generator::Base::VERSION = '0.4.2';
 use 5.006;
 
 use strict;
@@ -11,7 +11,7 @@ use parent 'Games::ABC_Path::Solver::Base';
 
 
 
-1; # End of Games::ABC_Path::Generator::Base
+1;    # End of Games::ABC_Path::Generator::Base
 
 __END__
 
@@ -25,16 +25,12 @@ Games::ABC_Path::Generator::Base - a base class.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
 B<For internal use.>.
 
-=head1 VERSION
-
-version 0.4.1
-
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
@@ -73,43 +69,13 @@ L<http://search.cpan.org/dist/Games-ABC_Path-Generator/>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Shlomi Fish.
-
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2019 by Shlomi Fish.
 
 This is free software, licensed under:
 
