@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator::FinalLayoutObj;
-$Games::ABC_Path::Generator::FinalLayoutObj::VERSION = '0.4.1';
+$Games::ABC_Path::Generator::FinalLayoutObj::VERSION = '0.4.2';
 use 5.006;
 
 use strict;
@@ -29,7 +29,7 @@ sub _init
     my $self = shift;
     my $args = shift;
 
-    $self->_s($args->{layout_string});
+    $self->_s( $args->{layout_string} );
 
     return;
 }
@@ -39,7 +39,7 @@ sub get_A_pos
 {
     my ($self) = @_;
 
-    return index($self->_s, chr(1));
+    return index( $self->_s, chr(1) );
 }
 
 
@@ -47,53 +47,53 @@ sub get_A_xy
 {
     my ($self) = @_;
 
-    my ($y, $x) = $self->_to_xy($self->get_A_pos());
+    my ( $y, $x ) = $self->_to_xy( $self->get_A_pos() );
 
-    return {y => $y, x => $x,};
+    return { y => $y, x => $x, };
 }
 
 
 sub get_cell_contents
 {
-    my ($self, $index) = @_;
+    my ( $self, $index ) = @_;
 
-    return vec($self->_s, $index, 8) ;
+    return vec( $self->_s, $index, 8 );
 }
 
 
 sub get_letter_at_pos
 {
-    my ($self, $pos) = @_;
+    my ( $self, $pos ) = @_;
 
     return $letters[
         $self->get_cell_contents(
-            $self->_xy_to_int(
-                [$pos->{'y'},$pos->{'x'}],
-            )
-        )-1,
+            $self->_xy_to_int( [ $pos->{'y'}, $pos->{'x'} ], ) ) - 1,
     ];
 }
 
 
 sub as_string
 {
-    my ($l, $args) = @_;
+    my ( $l, $args ) = @_;
 
     my $render_row = sub {
         my $y = shift;
 
-        return join(" | ",
+        return join(
+            " | ",
             map {
                 my $x = $_;
-                my $v = $l->get_cell_contents($l->_xy_to_int([$y,$x]));
-            $v ? $letters[$v-1] : '*' } (0 .. $LEN - 1));
+                my $v = $l->get_cell_contents( $l->_xy_to_int( [ $y, $x ] ) );
+                $v ? $letters[ $v - 1 ] : '*'
+            } ( 0 .. $LEN - 1 )
+        );
     };
 
-    return join('', map { $render_row->($_) . "\n" } (0 .. $LEN-1));
+    return join( '', map { $render_row->($_) . "\n" } ( 0 .. $LEN - 1 ) );
 }
 
 
-1; # End of Games::ABC_Path::Generator
+1;    # End of Games::ABC_Path::Generator
 
 __END__
 
@@ -107,7 +107,7 @@ Games::ABC_Path::Generator::FinalLayoutObj - represents a final layout.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
@@ -120,10 +120,6 @@ version 0.4.1
 
     my $A_xy = $layout->get_A_xy();
 
-=head1 VERSION
-
-version 0.4.1
-
 =head1 SUBROUTINES/METHODS
 
 =head2 my $layout = Games::ABC_Path::Generator::FinalLayoutObj->new({%args});
@@ -189,43 +185,13 @@ L<http://search.cpan.org/dist/Games-ABC_Path-Generator/>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Shlomi Fish.
-
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2019 by Shlomi Fish.
 
 This is free software, licensed under:
 
