@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator::RiddleObj;
-$Games::ABC_Path::Generator::RiddleObj::VERSION = '0.4.1';
+$Games::ABC_Path::Generator::RiddleObj::VERSION = '0.4.2';
 use 5.006;
 
 use strict;
@@ -55,9 +55,9 @@ sub _init
     my $self = shift;
     my $args = shift;
 
-    $self->_solution($args->{solution});
-    $self->_clues($args->{clues});
-    $self->_A_pos($args->{A_pos});
+    $self->_solution( $args->{solution} );
+    $self->_clues( $args->{clues} );
+    $self->_A_pos( $args->{A_pos} );
 
     return;
 }
@@ -65,14 +65,14 @@ sub _init
 
 sub get_letters_of_clue
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $get_index = sub {
         my $i = $args->{index};
 
-        if ($i !~ m{\A[01234]\z})
+        if ( $i !~ m{\A[01234]\z} )
         {
-            Carp::confess ('index must be in the range 0-4');
+            Carp::confess('index must be in the range 0-4');
         }
 
         return $i;
@@ -81,28 +81,28 @@ sub get_letters_of_clue
     my $clue_idx;
     my $type = $args->{type};
 
-    if ($type eq 'col')
+    if ( $type eq 'col' )
     {
         $clue_idx = 2 + $LEN + $get_index->();
     }
-    elsif ($type eq 'row')
+    elsif ( $type eq 'row' )
     {
         $clue_idx = 2 + $get_index->();
     }
-    elsif ($type eq 'diag')
+    elsif ( $type eq 'diag' )
     {
         $clue_idx = 0;
     }
-    elsif ($type eq 'antidiag')
+    elsif ( $type eq 'antidiag' )
     {
         $clue_idx = 1;
     }
     else
     {
-        Carp::confess ("Unknown type $type.");
+        Carp::confess("Unknown type $type.");
     }
 
-    return [map { $letters[$_-1] } @{$self->_clues->[$clue_idx]}];
+    return [ map { $letters[ $_ - 1 ] } @{ $self->_clues->[$clue_idx] } ];
 }
 
 
@@ -110,24 +110,27 @@ sub get_riddle_v1_string
 {
     my ($self) = @_;
 
-    my $s = ((' ' x 7)."\n")x7;
+    my $s = ( ( ' ' x 7 ) . "\n" ) x 7;
 
-    substr($s, ($self->_A_pos->y + 1) * 8 + $self->_A_pos->x + 1, 1) = 'A';
+    substr( $s, ( $self->_A_pos->y + 1 ) * 8 + $self->_A_pos->x + 1, 1 ) = 'A';
 
     my $clues = $self->_clues();
-    foreach my $clue_idx (0 .. $NUM_CLUES-1)
+    foreach my $clue_idx ( 0 .. $NUM_CLUES - 1 )
     {
         my @pos =
-            ($clue_idx == 0) ? ([0,0],[6,6])
-            : ($clue_idx == 1) ? ([0,6],[6,0])
-            : ($clue_idx < (2+5)) ? ([1+$clue_idx-(2), 0], [1+$clue_idx-(2), 6])
-            : ([0, 1+$clue_idx-(2+5)], [6, 1+$clue_idx-(2+5)])
-            ;
+              ( $clue_idx == 0 ) ? ( [ 0, 0 ], [ 6, 6 ] )
+            : ( $clue_idx == 1 ) ? ( [ 0, 6 ], [ 6, 0 ] )
+            : ( $clue_idx < ( 2 + 5 ) )
+            ? ( [ 1 + $clue_idx - (2), 0 ], [ 1 + $clue_idx - (2), 6 ] )
+            : (
+            [ 0, 1 + $clue_idx - ( 2 + 5 ) ],
+            [ 6, 1 + $clue_idx - ( 2 + 5 ) ]
+            );
 
-        foreach my $i (0 .. 1)
+        foreach my $i ( 0 .. 1 )
         {
-            substr ($s, $pos[$i][0] * 8 + $pos[$i][1], 1)
-                = $letters[$clues->[$clue_idx]->[$i] - 1];
+            substr( $s, $pos[$i][0] * 8 + $pos[$i][1], 1 ) =
+                $letters[ $clues->[$clue_idx]->[$i] - 1 ];
         }
     }
 
@@ -143,16 +146,15 @@ sub get_final_layout
 }
 
 
-
 sub get_final_layout_as_string
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     return $self->_solution->as_string($args);
 }
 
 
-1; # End of Games::ABC_Path::Generator
+1;    # End of Games::ABC_Path::Generator
 
 __END__
 
@@ -166,7 +168,7 @@ Games::ABC_Path::Generator::RiddleObj - represents a riddle.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
@@ -180,10 +182,6 @@ version 0.4.1
     print $riddle->get_riddle_v1_string();
     print $riddle->get_riddle_string_with_header();
 
-=head1 VERSION
-
-version 0.4.1
-
 =head1 SUBROUTINES/METHODS
 
 =head2 my $riddle = Games::ABC_Path::Generator::RiddleObj->new({%args});
@@ -289,43 +287,13 @@ L<http://search.cpan.org/dist/Games-ABC_Path-Generator/>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Shlomi Fish.
-
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2019 by Shlomi Fish.
 
 This is free software, licensed under:
 
