@@ -1,5 +1,5 @@
 package Games::ABC_Path::MicrosoftRand;
-$Games::ABC_Path::MicrosoftRand::VERSION = '0.4.1';
+$Games::ABC_Path::MicrosoftRand::VERSION = '0.4.2';
 use 5.006;
 use strict;
 use warnings;
@@ -9,33 +9,34 @@ use integer;
 
 use Class::XSAccessor {
     constructor => 'new',
-    accessors => [qw(seed)],
+    accessors   => [qw(seed)],
 };
 
 sub rand
 {
     my $self = shift;
-    $self->seed(($self->seed() * 214013 + 2531011) & (0x7FFF_FFFF));
-    return (($self->seed >> 16) & 0x7fff);
+    $self->seed( ( $self->seed() * 214013 + 2531011 ) & (0x7FFF_FFFF) );
+    return ( ( $self->seed >> 16 ) & 0x7fff );
 }
 
 sub max_rand
 {
-    my ($self, $max) = @_;
+    my ( $self, $max ) = @_;
 
-    return ($self->rand() % $max);
+    return ( $self->rand() % $max );
 }
 
 sub shuffle
 {
-    my ($self, $deck) = @_;
+    my ( $self, $deck ) = @_;
 
     if (@$deck)
     {
         my $i = @$deck;
-        while (--$i) {
-            my $j = $self->max_rand($i+1);
-            @$deck[$i,$j] = @$deck[$j,$i];
+        while ( --$i )
+        {
+            my $j = $self->max_rand( $i + 1 );
+            @$deck[ $i, $j ] = @$deck[ $j, $i ];
         }
     }
 
@@ -44,7 +45,7 @@ sub shuffle
 
 
 
-1; # End of Games::ABC_Path::MicrosoftRand
+1;    # End of Games::ABC_Path::MicrosoftRand
 
 __END__
 
@@ -59,7 +60,7 @@ with Visual C.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
@@ -77,10 +78,6 @@ of familiarity and accessibility, because it is commonly used to generate
 Freecell layouts in the Freecell world (see
 L<http://en.wikipedia.org/wiki/FreeCell_%28Windows%29> ).
 
-=head1 VERSION
-
-version 0.4.1
-
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -149,43 +146,13 @@ L<http://search.cpan.org/dist/Games-ABC_Path-Generator/>
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Shlomi Fish.
-
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2019 by Shlomi Fish.
 
 This is free software, licensed under:
 
